@@ -184,9 +184,6 @@ void PKTransaction::cleanup(PackageKit::Transaction::Exit exit, uint runtime)
         return;
     }
 
-    if (failed && m_newPackageStates.isEmpty())
-        m_newPackageStates.insert(PackageKit::Transaction::InfoAvailable, kTransform<QStringList>(m_apps, [](AbstractResource* res) { return res->packageName(); }));
-
     this->submitResolve();
     if (failed)
         setStatus(Transaction::DoneWithErrorStatus);
@@ -230,19 +227,25 @@ void PKTransaction::packageResolved(PackageKit::Transaction::Info info, const QS
 
 void PKTransaction::submitResolve()
 {
+    const auto backend = qobject_cast<PackageKitBackend*>(resource()->backend());
     QStringList needResolving;
-    foreach(const auto &pkgids, m_newPackageStates) {
-        foreach(const auto &pkgid, pkgids) {
-            needResolving += PackageKit::Daemon::packageName(pkgid);
-        }
-    }
+    for(auto it = m_newPackageStates.constBegin(), itEnd = m_newPackageStates.constEnd(); it != itEnd; ++it) {
+        auto state = it.key();
+        if (state == PackageKit::Transaction::InfoInstalling)
+            state = PackageKit::Transaction::InfoInstalled;
+        if (state == PackageKit::Transaction::InfoRemoving)
+            state = PackageKit::Transaction::InfoAvailable;
+        if (state != PackageKit::Transaction::InfoInstalled && state != PackageKit::Transaction::InfoAvailable)
+            continue;
 
-    if (!needResolving.isEmpty()) {
-        needResolving.removeDuplicates();
-        const auto backend = qobject_cast<PackageKitBackend*>(resource()->backend());
-        backend->clearPackages(needResolving);
-        backend->resolvePackages(needResolving);
-        backend->fetchUpdates();
+        foreach(const auto &pkgid, it.value()) {
+            const auto resources = backend->resourcesByPackageName(PackageKit::Daemon::packageName(pkgid));
+            for(auto res: resources) {
+                auto r = qobject_cast<PackageKitResource*>(res);
+                r->clearPackageIds();
+                r->addPackageId(state, pkgid, true);
+            }
+        }
     }
 }
 
@@ -263,7 +266,7 @@ void PKTransaction::eulaRequired(const QString& eulaID, const QString& packageID
 
 void PKTransaction::errorFound(PackageKit::Transaction::Error err, const QString& error)
 {
-    if (err == PackageKit::Transaction::ErrorNoLicenseAgreement)
+    if (err == PackageKit::Transaction::ErrorNoLicenseAgreement || err == PackageKit::Transaction::ErrorTransactionCancelled)
         return;
     qWarning() << "PackageKit error:" << err << PackageKitMessages::errorMessage(err) << error;
     Q_EMIT passiveMessage(PackageKitMessages::errorMessage(err));
